# coding: utf-8

# flake8: noqa
"""
    Doc Converter

    This api converts file formats of OpenXml and OpenOffice documents formats to vector files (e.g., svg)  # noqa: E501

    The version of the OpenAPI document: 0.1
    Contact: kevin@presalytics.io
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from presalytics.client.presalytics_doc_converter.models.file_to_convert import FileToConvert
from presalytics.client.presalytics_doc_converter.models.file_url import FileUrl
